import * as athena from '@aws-cdk/aws-athena';
import * as ec2 from '@aws-cdk/aws-ec2';
import * as events from '@aws-cdk/aws-events';
import * as glue from '@aws-cdk/aws-glue';
import * as iam from '@aws-cdk/aws-iam';
import * as lambda from '@aws-cdk/aws-lambda';
import * as s3 from '@aws-cdk/aws-s3';
import * as cdk from '@aws-cdk/core';
import { DataProduct } from './data-product';
import { DataSet } from './data-sets/data-set';
import { KinesisStream } from './data-streams/kinesis-stream';
import { GlueJobType, GlueVersion, GlueWorkerType } from './etl/glue-job';
/**
 * @experimental
 */
export interface CrossAccountProperties {
    /**
     * @experimental
     */
    readonly consumerAccountIds: string[];
    /**
     * @experimental
     */
    readonly producerAccountId: string;
    /**
     * @experimental
     */
    readonly region: string;
}
/**
 * @experimental
 */
export interface DataLakeProperties {
    /**
     * @experimental
     */
    readonly name: string;
    /**
     * @experimental
     */
    readonly stageName: Stage;
    /**
     * @experimental
     */
    readonly accountId: string;
    /**
     * @experimental
     */
    readonly region: string;
    /**
     * @experimental
     */
    readonly dataProducts?: DataProduct[];
    /**
     * @experimental
     */
    readonly vpc?: ec2.Vpc;
    /**
     * @experimental
     */
    readonly policyTags?: {
        [name: string]: string;
    };
    /**
     * @experimental
     */
    readonly crossAccount?: CrossAccountProperties;
    /**
     * @experimental
     */
    readonly glueSecurityGroup?: ec2.SecurityGroup;
    /**
     * @experimental
     */
    readonly datalakeAdminRole?: iam.Role;
    /**
     * @experimental
     */
    readonly datalakeCreatorRole?: iam.Role;
    /**
     * @experimental
     */
    readonly createDefaultDatabase: Boolean;
}
/**
 * @experimental
 */
export interface JDBCProperties {
    /**
     * @experimental
     */
    readonly jdbc: string;
    /**
     * @experimental
     */
    readonly username: string;
    /**
     * @experimental
     */
    readonly password: string;
}
/**
 * @experimental
 */
export interface StreamProperties {
    /**
     * @experimental
     */
    readonly streamName: string;
    /**
     * @experimental
     */
    readonly lambdaDataGenerator?: LambdaDataGeneratorProperties;
}
/**
 * @experimental
 */
export interface S3Properties {
    /**
     * @experimental
     */
    readonly sourceBucketName: string;
    /**
     * @experimental
     */
    readonly sourceKeys: string[];
}
/**
 * @experimental
 */
export interface TableProps {
    /**
     * @experimental
     */
    readonly tableName: string;
    /**
     * @experimental
     */
    readonly description: string;
    /**
     * @experimental
     */
    readonly partitionKeys: Array<glue.CfnTable.ColumnProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * @experimental
     */
    readonly columns: Array<glue.CfnTable.ColumnProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * @experimental
     */
    readonly parameters: {
        [param: string]: any;
    };
    /**
     * @experimental
     */
    readonly serializationLibrary: string;
    /**
     * @experimental
     */
    readonly serdeParameters: {
        [param: string]: any;
    };
    /**
     * @experimental
     */
    readonly inputFormat: string;
    /**
     * @experimental
     */
    readonly outputFormat: string;
    /**
     * @experimental
     */
    readonly catalogId: string;
}
/**
 * @experimental
 */
export interface JobProperties {
    /**
     * @experimental
     */
    readonly name: string;
    /**
     * @experimental
     */
    readonly roleName?: string;
    /**
     * @experimental
     */
    readonly description?: string;
    /**
     * @experimental
     */
    readonly readAccessBuckets?: s3.IBucket[];
    /**
     * @experimental
     */
    readonly writeAccessBuckets?: s3.IBucket[];
    /**
     * @experimental
     */
    readonly glueVersion?: GlueVersion;
    /**
     * @experimental
     */
    readonly workerType: GlueWorkerType;
    /**
     * @experimental
     */
    readonly numberOfWorkers?: number;
    /**
     * @experimental
     */
    readonly maxCapacity?: number;
    /**
     * @experimental
     */
    readonly maxRetries?: number;
    /**
     * @experimental
     */
    readonly maxConcurrentRuns?: number;
    /**
     * @experimental
     */
    readonly jobScript: string;
    /**
     * @experimental
     */
    readonly jobArgs?: {
        [key: string]: string;
    };
    /**
     * @experimental
     */
    readonly timeout?: number;
    /**
     * @experimental
     */
    readonly jobType: GlueJobType;
    /**
     * @experimental
     */
    readonly destinationLocation?: DataSetLocation;
}
/**
 * @experimental
 */
export interface DataLocationProperties {
    /**
     * @experimental
     */
    readonly destinationPrefix: string;
    /**
     * @experimental
     */
    readonly destinationBucketName: string;
    /**
     * @experimental
     */
    readonly name: string;
    /**
     * @experimental
     */
    readonly databaseName: string;
}
/**
 * @experimental
 */
export interface DataStreamProperties {
    /**
     * @experimental
     */
    readonly name: string;
    /**
     * @experimental
     */
    readonly destinationBucketName: string;
    /**
     * @experimental
     */
    readonly destinationPrefix: string;
    /**
     * @experimental
     */
    readonly dataCatalogOwner: DataCatalogOwner;
    /**
     * @experimental
     */
    readonly streamName: string;
    /**
     * @experimental
     */
    readonly lambdaDataGenerator: LambdaDataGeneratorProperties;
}
/**
 * @experimental
 */
export interface LambdaDataGeneratorProperties {
    /**
     * @experimental
     */
    readonly code: lambda.Code;
    /**
     * @experimental
     */
    readonly handler: string;
    /**
     * @experimental
     */
    readonly timeout: cdk.Duration;
    /**
     * @experimental
     */
    readonly runtime: lambda.Runtime;
    /**
     * @experimental
     */
    readonly functionName: string;
    /**
     * @experimental
     */
    readonly schedule: events.Schedule;
    /**
     * @experimental
     */
    readonly ruleName: string;
}
/**
 * @experimental
 */
export interface DataCatalogOwner {
    /**
     * @experimental
     */
    readonly accountId: string;
}
/**
 * @experimental
 */
export interface S3NotificationProperties {
    /**
     * @experimental
     */
    readonly event: s3.EventType;
    /**
     * @experimental
     */
    readonly prefix: string;
    /**
     * @experimental
     */
    readonly suffix: string;
}
/**
 * @experimental
 */
export declare enum DataPipelineType {
    /**
     * @experimental
     */
    STREAM = "stream",
    /**
     * @experimental
     */
    JDBC = "jdbc",
    /**
     * @experimental
     */
    S3 = "s3"
}
/**
 * @experimental
 */
export declare enum Stage {
    /**
     * @experimental
     */
    ALPHA = "alpha",
    /**
     * @experimental
     */
    BETA = "beta",
    /**
     * @experimental
     */
    GAMMA = "gamma",
    /**
     * @experimental
     */
    PROD = "prod"
}
/**
 * @experimental
 */
export declare enum Permissions {
    /**
     * @experimental
     */
    ALTER = "ALTER",
    /**
     * @experimental
     */
    CREATE_DATABASE = "CREATE_DATABASE",
    /**
     * @experimental
     */
    CREATE_TABLE = "CREATE_TABLE",
    /**
     * @experimental
     */
    DATA_LOCATION_ACCESS = "DATA_LOCATION_ACCESS",
    /**
     * @experimental
     */
    DELETE = "DELETE",
    /**
     * @experimental
     */
    DESCRIBE = "DESCRIBE",
    /**
     * @experimental
     */
    DROP = "DROP",
    /**
     * @experimental
     */
    INSERT = "INSERT",
    /**
     * @experimental
     */
    SELECT = "SELECT",
    /**
     * @experimental
     */
    ASSOCIATE = "ASSOCIATE"
}
/**
 * @experimental
 */
export declare enum DataSetLocation {
    /**
     * @experimental
     */
    RAW = "raw",
    /**
     * @experimental
     */
    TRUSTED = "trusted",
    /**
     * @experimental
     */
    REFINED = "refined"
}
/**
 * @experimental
 */
export declare class DataLake extends cdk.Construct {
    /**
     * @experimental
     */
    readonly dataSets: {
        [schemaName: string]: DataSet;
    };
    /**
     * @experimental
     */
    readonly dataStreams: {
        [schemaName: string]: KinesisStream;
    };
    /**
     * @experimental
     */
    readonly logBucket: s3.Bucket;
    /**
     * @experimental
     */
    readonly databases: {
        [name: string]: glue.Database;
    };
    /**
     * @experimental
     */
    readonly datalakeAdminRole: iam.IRole;
    /**
     * @experimental
     */
    readonly datalakeDbCreatorRole: iam.IRole;
    /**
     * @experimental
     */
    readonly athenaWorkgroup: athena.CfnWorkGroup;
    /**
     * @experimental
     */
    readonly region: string;
    /**
     * @experimental
     */
    readonly accountId: string;
    /**
     * @experimental
     */
    readonly stageName: Stage;
    /**
     * @experimental
     */
    readonly vpc?: ec2.Vpc;
    private readonly glueSecurityGroup?;
    private readonly crossAccountAccess?;
    private readonly downloadLocations;
    /**
     * @experimental
     */
    constructor(scope: cdk.Construct, id: string, props: DataLakeProperties);
    /**
     * @experimental
     */
    createDownloaderCustomResource(accountId: string, region: string, stageName: string): void;
    private addDataSet;
    private createDatabase;
    private addDataStream;
    private addPipeline;
    private registerDataSetWithLakeFormation;
    private createPolicyTagsCustomResource;
    private createCrossAccountGlueCatalogResourcePolicy;
}
